@@ -7,16 +7,13 @@ const ITEM_SIZE: u32 = 5000;
 // Generate benchmark tests
 pub fn bench_insert(c: &mut Criterion) {
     // Generate a new database
-    let path = format!("data/bench_insert");
+    let path = "data/bench_insert";
 
-    match std::fs::remove_dir_all(&path) {
-        Ok(()) => (),
-        // Silently ignore, 99% of the time this will already be removed.
-        Err(_) => (),
-    }
+    // Silently ignore, 99% of the time this will already be removed
+    let _ = std::fs::remove_dir_all(path);
 
     let config = sled::Config::default()
-        .path(path)
+        .path(path.to_string())
         .temporary(true)
         .mode(sled::Mode::HighThroughput);
 
@@ -53,16 +50,13 @@ pub fn bench_insert(c: &mut Criterion) {
 
 pub fn bench_select(c: &mut Criterion) {
     // Generate a new database
-    let path = format!("data/bench_select");
+    let path = "data/bench_select";
 
-    match std::fs::remove_dir_all(&path) {
-        Ok(()) => (),
-        // Silently ignore, 99% of the time this will already be removed.
-        Err(_) => (),
-    }
+    // Silently ignore, 99% of the time this will already be removed
+    let _ = std::fs::remove_dir_all(path);
 
     let config = sled::Config::default()
-        .path(path)
+        .path(path.to_string())
         .temporary(true)
         .mode(sled::Mode::HighThroughput);
 
@@ -126,16 +120,13 @@ pub fn bench_select(c: &mut Criterion) {
 
 pub fn bench_select_tainted(c: &mut Criterion) {
     // Generate a new database
-    let path = format!("data/bench_select_tainted");
+    let path = "data/bench_select_tainted";
 
-    match std::fs::remove_dir_all(&path) {
-        Ok(()) => (),
-        // Silently ignore, 99% of the time this will already be removed.
-        Err(_) => (),
-    }
+    // Silently ignore, 99% of the time this will already be removed
+    let _ = std::fs::remove_dir_all(path);
 
     let config = sled::Config::default()
-        .path(path)
+        .path(path.to_string())
         .temporary(true)
         .mode(sled::Mode::HighThroughput);
 
