@@ -45,8 +45,7 @@ mod hello_world {
         };
 
         let first_row = &rows[0];
-        let first_row_unwrapped = &first_row.0;
-        let first_value = &first_row_unwrapped[0];
+        let first_value = &first_row[0];
 
         /*
             Row values are wrapped into a value enum, on the basis of the result type
