@@ -27,7 +27,7 @@ mod sled_multi_threaded {
             glue.execute(query).unwrap();
         });
 
-        let world_storage = storage.clone();
+        let world_storage = storage;
         let world_thread = thread::spawn(move || {
             let mut glue = Glue::new(world_storage);
             let query = "INSERT INTO greet (name) VALUES (\"World\")";
@@ -52,8 +52,7 @@ mod sled_multi_threaded {
         };
 
         let first_row = &rows[0];
-        let first_row_unwrapped = &first_row.0;
-        let first_value = &first_row_unwrapped[0];
+        let first_value = &first_row[0];
         let to_greet = match first_value {
             Value::Str(to_greet) => to_greet,
             value => panic!("Unexpected type: {:?}", value),
