@@ -1,4 +1,5 @@
 use {
+    super::StringExt,
     crate::{
         ast::AstLiteral,
         result::{Error, Result},
@@ -22,6 +23,9 @@ pub enum LiteralError {
 
     #[error("unreachable literal unary operation")]
     UnreachableUnaryOperation,
+
+    #[error("operator doesn't exist: {0:?} LIKE {1:?}")]
+    LikeOnNonString(String, String),
 }
 
 #[derive(Clone, Debug)]
@@ -266,6 +270,15 @@ impl<'a> Literal<'a> {
             .into()),
         }
     }
+
+    pub fn like(&self, other: &Literal<'a>) -> Result<Self> {
+        match (self, other) {
+            (Text(l), Text(r)) => l.like(r).map(Boolean),
+            _ => Err(
+                LiteralError::LikeOnNonString(format!("{:?}", self), format!("{:?}", other)).into(),
+            ),
+        }
+    }
 }
 
 #[cfg(test)]
