@@ -1,6 +1,7 @@
 mod interval;
 mod literal;
 mod row;
+mod string_ext;
 mod table;
 
 pub mod schema;
@@ -11,6 +12,7 @@ pub use {
     literal::{Literal, LiteralError},
     row::{Row, RowError},
     schema::{Schema, SchemaIndex, SchemaIndexOrd},
+    string_ext::{StringExt, StringExtError},
     table::{get_name, Table, TableError},
     value::{Value, ValueError},
 };
