@@ -1,5 +1,6 @@
 use {
     super::Interval,
+    super::StringExt,
     crate::{ast::DataType, result::Result},
     chrono::{NaiveDate, NaiveDateTime, NaiveTime},
     core::ops::Sub,
@@ -283,12 +284,22 @@ impl Value {
             _ => Err(ValueError::UnaryMinusOnNonNumeric.into()),
         }
     }
+
+    pub fn like(&self, other: &Value) -> Result<Value> {
+        use Value::*;
+
+        match (self, other) {
+            (Str(a), Str(b)) => a.like(b).map(Bool),
+            _ => Err(ValueError::LikeOnNonString(self.clone(), other.clone()).into()),
+        }
+    }
 }
 
 #[cfg(test)]
 mod tests {
     use super::{Interval, Value::*};
 
+    #[allow(clippy::eq_op)]
     #[test]
     fn eq() {
         use super::Interval;
