@@ -15,7 +15,6 @@ use {
         result::{Error, Result},
         store::GStore,
     },
-    boolinator::Boolinator,
     futures::stream::{self, StreamExt, TryStream, TryStreamExt},
     std::{convert::TryFrom, fmt::Debug, pin::Pin, rc::Rc},
 };
@@ -90,7 +89,7 @@ impl<'a, T: 'static + Debug> Aggregator<'a, T> {
                     .fields
                     .iter()
                     .try_fold(state, |state, field| match field {
-                        SelectItem::Expr { expr, .. } => aggregate(state, &blend_context, &expr),
+                        SelectItem::Expr { expr, .. } => aggregate(state, &blend_context, expr),
                         _ => Ok(state),
                     })?;
 
@@ -127,17 +126,18 @@ impl<'a, T: 'static + Debug> Aggregator<'a, T> {
                                 having,
                             )
                             .await
-                            .map(|pass| pass.as_some((aggregated, next)))
+                            .map(|pass| pass.then(|| (aggregated, next)))
                             .transpose()
                         }
                     }
                 }
             })
-            .map_ok(|(aggregated, next)| {
-                // TODO: Remove unwrap!
-                let aggregated = aggregated.map(|a| Rc::try_unwrap(a).unwrap());
-
-                AggregateContext { aggregated, next }
+            .and_then(|(aggregated, next): (Option<_>, _)| async move {
+                aggregated
+                    .map(Rc::try_unwrap)
+                    .transpose()
+                    .map_err(|_| AggregateError::UnreachableRcUnwrapFailure.into())
+                    .map(|aggregated| AggregateContext { aggregated, next })
             });
 
         Ok(Box::pin(rows))
@@ -167,7 +167,7 @@ fn aggregate<'a>(
     let aggr = |state, expr| aggregate(state, context, expr);
     let get_value = |expr: &Expr| match expr {
         Expr::Identifier(ident) => context
-            .get_value(&ident)
+            .get_value(ident)
             .ok_or_else(|| AggregateError::ValueNotFound(ident.to_string())),
         Expr::CompoundIdentifier(idents) => {
             if idents.len() != 2 {
