@@ -16,12 +16,18 @@ pub enum EvaluateError {
     #[error("function requires string value: {0}")]
     FunctionRequiresStringValue(String),
 
-    #[error("function requires string value: {0}")]
+    #[error("function requires integer value: {0}")]
     FunctionRequiresIntegerValue(String),
 
+    #[error("function requires float or integer value: {0}")]
+    FunctionRequiresFloatOrIntegerValue(String),
+
     #[error("function requires usize value: {0}")]
     FunctionRequiresUSizeValue(String),
 
+    #[error("function requires float value: {0}")]
+    FunctionRequiresFloatValue(String),
+
     #[error("value not found: {0}")]
     ValueNotFound(String),
 
@@ -42,4 +48,7 @@ pub enum EvaluateError {
 
     #[error("unreachable empty aggregate value: {0:?}")]
     UnreachableEmptyAggregateValue(Aggregate),
+
+    #[error("divisor should not be zero")]
+    InvalidDivisorZero,
 }
