@@ -12,7 +12,6 @@ use {
         store::GStore,
     },
     async_recursion::async_recursion,
-    boolinator::Boolinator,
     futures::stream::{self, StreamExt, TryStreamExt},
     im_rc::HashMap,
     std::{
@@ -42,18 +41,18 @@ pub async fn evaluate<'a, T: 'static + Debug>(
     match expr {
         Expr::Literal(ast_literal) => expr::literal(ast_literal),
         Expr::TypedString { data_type, value } => {
-            expr::typed_string(data_type, Cow::Borrowed(&value))
+            expr::typed_string(data_type, Cow::Borrowed(value))
         }
         Expr::Identifier(ident) => {
             let context = context.ok_or(EvaluateError::UnreachableEmptyContext)?;
 
-            match context.get_value(&ident) {
+            match context.get_value(ident) {
                 Some(value) => Ok(value.clone()),
                 None => Err(EvaluateError::ValueNotFound(ident.to_string()).into()),
             }
             .map(Evaluated::from)
         }
-        Expr::Nested(expr) => eval(&expr).await,
+        Expr::Nested(expr) => eval(expr).await,
         Expr::CompoundIdentifier(idents) => {
             if idents.len() != 2 {
                 return Err(EvaluateError::UnsupportedCompoundIdentifier(expr.clone()).into());
@@ -69,7 +68,7 @@ pub async fn evaluate<'a, T: 'static + Debug>(
             }
             .map(Evaluated::from)
         }
-        Expr::Subquery(query) => select(storage, &query, context.as_ref().map(Rc::clone))
+        Expr::Subquery(query) => select(storage, query, context.as_ref().map(Rc::clone))
             .await?
             .map_ok(|row| row.take_first_value().map(Evaluated::from))
             .take(1)
@@ -119,7 +118,7 @@ pub async fn evaluate<'a, T: 'static + Debug>(
                     async move {
                         eval(expr).await.map_or_else(
                             |error| Some(Err(error)),
-                            |evaluated| (target == &evaluated).as_some(Ok(!negated)),
+                            |evaluated| (target == &evaluated).then(|| Ok(!negated)),
                         )
                     }
                 })
@@ -139,7 +138,7 @@ pub async fn evaluate<'a, T: 'static + Debug>(
         } => {
             let target = eval(expr).await?;
 
-            select(storage, &subquery, context)
+            select(storage, subquery, context)
                 .await?
                 .try_filter_map(|row| {
                     let target = &target;
@@ -148,7 +147,7 @@ pub async fn evaluate<'a, T: 'static + Debug>(
                         let value = row.take_first_value()?;
 
                         (target == &Evaluated::from(&value))
-                            .as_some(Ok(!negated))
+                            .then(|| Ok(!negated))
                             .transpose()
                     }
                 })
@@ -219,23 +218,44 @@ async fn evaluate_function<'a, T: 'static + Debug>(
         Null,
     }
 
-    let eval_to_str = |name: &'static str, expr| async move {
+    let eval_to_str = |expr| async move {
         match eval(expr).await?.try_into()? {
             Value::Str(s) => Ok(Nullable::Value(s)),
             Value::Null => Ok(Nullable::Null),
             _ => {
-                Err::<_, Error>(EvaluateError::FunctionRequiresStringValue(name.to_owned()).into())
+                Err::<_, Error>(EvaluateError::FunctionRequiresStringValue(func.to_string()).into())
             }
         }
     };
 
+    let eval_to_float = |expr| async move {
+        match eval(expr).await?.try_into()? {
+            Value::I64(v) => Ok(Nullable::Value(v as f64)),
+            Value::F64(v) => Ok(Nullable::Value(v)),
+            Value::Null => Ok(Nullable::Null),
+            _ => {
+                Err::<_, Error>(EvaluateError::FunctionRequiresFloatValue(func.to_string()).into())
+            }
+        }
+    };
+
+    let eval_to_integer = |expr| async move {
+        match eval(expr).await?.try_into()? {
+            Value::I64(number) => Ok(Nullable::Value(number)),
+            Value::Null => Ok(Nullable::Null),
+            _ => Err::<_, Error>(
+                EvaluateError::FunctionRequiresIntegerValue(func.to_string()).into(),
+            ),
+        }
+    };
+
     match func {
-        Function::Lower(expr) => match eval_to_str("LOWER", expr).await? {
+        Function::Lower(expr) => match eval_to_str(expr).await? {
             Nullable::Value(v) => Ok(Value::Str(v.to_lowercase())),
             Nullable::Null => Ok(Value::Null),
         }
         .map(Evaluated::from),
-        Function::Upper(expr) => match eval_to_str("UPPER", expr).await? {
+        Function::Upper(expr) => match eval_to_str(expr).await? {
             Nullable::Value(v) => Ok(Value::Str(v.to_uppercase())),
             Nullable::Null => Ok(Value::Null),
         }
@@ -247,7 +267,7 @@ async fn evaluate_function<'a, T: 'static + Debug>(
                 "RIGHT"
             };
 
-            let string = match eval_to_str(name, expr).await? {
+            let string = match eval_to_str(expr).await? {
                 Nullable::Value(v) => v,
                 Nullable::Null => {
                     return Ok(Evaluated::from(Value::Null));
@@ -282,5 +302,130 @@ async fn evaluate_function<'a, T: 'static + Debug>(
 
             Ok(Evaluated::from(Value::Str(converted)))
         }
+        Function::Ceil(expr) => match eval_to_float(expr).await? {
+            Nullable::Value(v) => Ok(Value::F64(v.ceil())),
+            Nullable::Null => Ok(Value::Null),
+        }
+        .map(Evaluated::from),
+        Function::Round(expr) => match eval_to_float(expr).await? {
+            Nullable::Value(v) => Ok(Value::F64(v.round())),
+            Nullable::Null => Ok(Value::Null),
+        }
+        .map(Evaluated::from),
+        Function::Floor(expr) => match eval_to_float(expr).await? {
+            Nullable::Value(v) => Ok(Value::F64(v.floor())),
+            Nullable::Null => Ok(Value::Null),
+        }
+        .map(Evaluated::from),
+        Function::Trim(expr) => match eval_to_str(expr).await? {
+            Nullable::Value(string) => Ok(Value::Str(string.trim().to_owned())),
+            Nullable::Null => Ok(Value::Null),
+        }
+        .map(Evaluated::from),
+        Function::Sin(expr) | Function::Cos(expr) | Function::Tan(expr) => {
+            let float_number = eval_to_float(expr).await?;
+
+            let trigonometric = |func, value| match func {
+                Function::Sin(_) => f64::sin(value),
+                Function::Cos(_) => f64::cos(value),
+                _ => f64::tan(value),
+            };
+
+            match float_number {
+                Nullable::Value(v) => Ok(Value::F64(trigonometric(func.to_owned(), v))),
+                Nullable::Null => Ok(Value::Null),
+            }
+            .map(Evaluated::from)
+        }
+        Function::Div { dividend, divisor } | Function::Mod { dividend, divisor } => {
+            let name = if matches!(func, Function::Div { .. }) {
+                "DIV"
+            } else {
+                "MOD"
+            };
+
+            let dividend = match eval(dividend).await?.try_into()? {
+                Value::F64(number) => number,
+                Value::I64(number) => number as f64,
+                Value::Null => {
+                    return Ok(Evaluated::from(Value::Null));
+                }
+                _ => {
+                    return Err(EvaluateError::FunctionRequiresFloatOrIntegerValue(
+                        name.to_owned(),
+                    )
+                    .into());
+                }
+            };
+
+            let divisor = match eval(divisor).await?.try_into()? {
+                Value::F64(number) => match number {
+                    x if x == 0.0 => return Err(EvaluateError::InvalidDivisorZero.into()),
+                    _ => number,
+                },
+                Value::I64(number) => match number {
+                    0 => return Err(EvaluateError::InvalidDivisorZero.into()),
+                    _ => number as f64,
+                },
+                Value::Null => {
+                    return Ok(Evaluated::from(Value::Null));
+                }
+                _ => {
+                    return Err(EvaluateError::FunctionRequiresFloatOrIntegerValue(
+                        name.to_owned(),
+                    )
+                    .into());
+                }
+            };
+
+            match name {
+                "DIV" => Ok(Evaluated::from(Value::I64((dividend / divisor) as i64))),
+                _ => Ok(Evaluated::from(Value::F64(dividend % divisor))),
+            }
+        }
+        Function::Gcd { left, right } => {
+            let left = match eval_to_integer(left).await? {
+                Nullable::Value(v) => v,
+                Nullable::Null => {
+                    return Ok(Evaluated::from(Value::Null));
+                }
+            };
+            let right = match eval_to_integer(right).await? {
+                Nullable::Value(v) => v,
+                Nullable::Null => {
+                    return Ok(Evaluated::from(Value::Null));
+                }
+            };
+
+            Ok(Evaluated::from(Value::I64(gcd(left, right))))
+        }
+        Function::Lcm { left, right } => {
+            let left = match eval_to_integer(left).await? {
+                Nullable::Value(v) => v,
+                Nullable::Null => {
+                    return Ok(Evaluated::from(Value::Null));
+                }
+            };
+            let right = match eval_to_integer(right).await? {
+                Nullable::Value(v) => v,
+                Nullable::Null => {
+                    return Ok(Evaluated::from(Value::Null));
+                }
+            };
+
+            fn lcm(a: i64, b: i64) -> i64 {
+                a * b / gcd(a, b)
+            }
+
+            Ok(Evaluated::from(Value::I64(lcm(left, right))))
+        }
+    }
+}
+
+fn gcd(a: i64, b: i64) -> i64 {
+    if b == 0 {
+        a
+    } else {
+        gcd(b, a % b)
     }
 }
