@@ -8,7 +8,7 @@ use {
     },
     crate::{
         ast::{Query, SetExpr, Statement, Values},
-        data::{get_name, Row, Schema},
+        data::{get_name, Row, Schema, Value},
         result::{MutResult, Result},
         store::{GStore, GStoreMut},
     },
@@ -36,7 +36,7 @@ pub enum Payload {
     Insert(usize),
     Select {
         labels: Vec<String>,
-        rows: Vec<Row>,
+        rows: Vec<Vec<Value>>,
     },
     Delete(usize),
     Update(usize),
@@ -50,6 +50,43 @@ pub enum Payload {
 
     #[cfg(feature = "index")]
     DropIndex,
+
+    #[cfg(feature = "transaction")]
+    StartTransaction,
+    #[cfg(feature = "transaction")]
+    Commit,
+    #[cfg(feature = "transaction")]
+    Rollback,
+}
+
+#[cfg(feature = "transaction")]
+pub async fn execute_atomic<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
+    storage: U,
+    statement: &Statement,
+) -> MutResult<U, Payload> {
+    if matches!(
+        statement,
+        Statement::StartTransaction | Statement::Rollback | Statement::Commit
+    ) {
+        return execute(storage, statement).await;
+    }
+
+    let (storage, autocommit) = storage.begin(true).await?;
+    let result = execute(storage, statement).await;
+
+    match (result, autocommit) {
+        (Ok((storage, payload)), true) => {
+            let (storage, ()) = storage.commit().await?;
+
+            Ok((storage, payload))
+        }
+        (Err((storage, error)), true) => {
+            let (storage, ()) = storage.rollback().await?;
+
+            Err((storage, error))
+        }
+        (result, _) => result,
+    }
 }
 
 pub async fn execute<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
@@ -99,6 +136,22 @@ pub async fn execute<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
         Statement::DropIndex { name, table_name } => drop_index(storage, table_name, name)
             .await
             .map(|(storage, _)| (storage, Payload::DropIndex)),
+        //- Transaction
+        #[cfg(feature = "transaction")]
+        Statement::StartTransaction => storage
+            .begin(false)
+            .await
+            .map(|(storage, _)| (storage, Payload::StartTransaction)),
+        #[cfg(feature = "transaction")]
+        Statement::Commit => storage
+            .commit()
+            .await
+            .map(|(storage, _)| (storage, Payload::Commit)),
+        #[cfg(feature = "transaction")]
+        Statement::Rollback => storage
+            .rollback()
+            .await
+            .map(|(storage, _)| (storage, Payload::Rollback)),
         //-- Rows
         Statement::Insert {
             table_name,
@@ -144,7 +197,7 @@ pub async fn execute<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
                     }
                 };
 
-                validate_unique(&storage, &table_name, column_validation, rows.iter()).await?;
+                validate_unique(&storage, table_name, column_validation, rows.iter()).await?;
 
                 Ok((rows, table_name))
             });
@@ -189,7 +242,7 @@ pub async fn execute<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
                     ColumnValidation::SpecifiedColumns(Rc::from(column_defs), columns_to_update);
                 validate_unique(
                     &storage,
-                    &table_name,
+                    table_name,
                     column_validation,
                     rows.iter().map(|r| &r.1),
                 )
@@ -210,7 +263,7 @@ pub async fn execute<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
             selection,
         } => {
             let (table_name, keys) = try_block!(storage, {
-                let table_name = get_name(&table_name)?;
+                let table_name = get_name(table_name)?;
                 let columns = Rc::from(fetch_columns(&storage, table_name).await?);
 
                 let keys = fetch(&storage, table_name, columns, selection.as_ref())
@@ -233,8 +286,11 @@ pub async fn execute<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
         //- Selection
         Statement::Query(query) => {
             let (labels, rows) = try_block!(storage, {
-                let (labels, rows) = select_with_labels(&storage, &query, None, true).await?;
-                let rows = rows.try_collect::<Vec<_>>().await?;
+                let (labels, rows) = select_with_labels(&storage, query, None, true).await?;
+                let rows = rows
+                    .map_ok(|Row(values)| values)
+                    .try_collect::<Vec<_>>()
+                    .await?;
 
                 Ok((labels, rows))
             });
