@@ -1,5 +1,5 @@
 #[cfg(feature = "sled-storage")]
-mod sled_storage;
+pub mod sled_storage;
 
 #[cfg(feature = "sled-storage")]
 pub use sled_storage::SledStorage;
