@@ -1,7 +1,7 @@
 use {
     crate::{
         ast::{Expr, IndexItem, Query, SetExpr, Statement, TableFactor},
-        data::{Row, Value},
+        data::Value,
         executor::{execute, Payload},
         parse_sql::{parse, parse_expr},
         plan::plan,
@@ -61,10 +61,7 @@ pub fn test(expected: Result<Payload>, found: Result<Payload>) {
 
     let rows = expected.into_iter().zip(found.into_iter()).enumerate();
 
-    for (i, (expected, found)) in rows.into_iter() {
-        let Row(expected) = expected;
-        let Row(found) = found;
-
+    for (i, (expected, found)) in rows {
         assert_eq!(
             expected.len(),
             found.len(),
@@ -116,8 +113,25 @@ pub async fn run<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
     let statement = try_run!(translate(&parsed[0]));
     let statement = try_run!(plan(&storage, statement).await);
 
+    test_indexes(&statement, indexes);
+
+    match execute(storage, &statement).await {
+        Ok((storage, payload)) => {
+            cell.replace(Some(storage));
+
+            Ok(payload)
+        }
+        Err((storage, error)) => {
+            cell.replace(Some(storage));
+
+            Err(error)
+        }
+    }
+}
+
+pub fn test_indexes(statement: &Statement, indexes: Option<Vec<IndexItem>>) {
     if let Some(expected) = indexes {
-        let found = find_indexes(&statement);
+        let found = find_indexes(statement);
 
         if expected.len() != found.len() {
             panic!(
@@ -136,19 +150,6 @@ pub async fn run<T: 'static + Debug, U: GStore<T> + GStoreMut<T>>(
             }
         }
     }
-
-    match execute(storage, &statement).await {
-        Ok((storage, payload)) => {
-            cell.replace(Some(storage));
-
-            Ok(payload)
-        }
-        Err((storage, error)) => {
-            cell.replace(Some(storage));
-
-            Err(error)
-        }
-    }
 }
 
 fn find_indexes(statement: &Statement) -> Vec<&IndexItem> {
@@ -188,7 +189,7 @@ fn find_indexes(statement: &Statement) -> Vec<&IndexItem> {
     }
 
     match statement {
-        Statement::Query(query) => find_query_indexes(&query),
+        Statement::Query(query) => find_query_indexes(query),
         _ => vec![],
     }
 }
