@@ -79,7 +79,7 @@ CREATE TABLE TestC (
         ),
     ];
 
-    for (error, sql) in error_cases.into_iter() {
+    for (error, sql) in error_cases {
         test!(Err(error), sql);
     }
 });
